@@ -155,7 +155,7 @@ flux_plot <- function(slopes_df,
     geom_text(
       data = slopes_params$param_df,
       aes(
-        x = .data$f_start, y = y_text_position,
+        x = .data$f_start_og, y = y_text_position,
         label = .data$print_col
       ),
       vjust = 0, hjust = "inward",
